package api

import (
	"3dshow/db/model"
	"3dshow/db/repo"
	"errors"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func Collect(r *GinRouter) {

	CreateCRUD(r, "/collect", &CRUDOption{
		Collection: repo.CollectionCollect,
		NewModel: func(c *gin.Context, apictx *ApiSession) (interface{}, error) {
			entity := &model.Collect{}
			c.ShouldBindJSON(entity)
			entity.CreateTime = time.Now()
			_userId := apictx.User.ID
			userId, err := primitive.ObjectIDFromHex(_userId)
			if err != nil {
				return nil, errors.New("非法用户")
			}
			entity.UserId = userId
			return entity, nil
		},
		EmtyModel: func(c *gin.Context, apictx *ApiSession) interface{} {
			return &model.Collect{}
		},
		JWT: true,
		SearchFilter: func(c *gin.Context, apictx *ApiSession, query map[string]interface{}) map[string]interface{} {
			_userId := apictx.User.ID
			userId, err := primitive.ObjectIDFromHex(_userId)
			if err != nil {
				// 6369f4b028c4bf8b14f47a6b
				invalidId, _ := primitive.ObjectIDFromHex("6369f4b028c4bf8b14f47a6b")
				return repo.Map{"userId": invalidId}
			}

			return repo.Map{"userId": userId}
		},
		SearchPostProcess: func(page *repo.PageResult, c *gin.Context, apictx *ApiSession, query map[string]interface{}) (interface{}, error) {
			// 查询组装数据
			if len(page.List) > 0 {
				for _, v := range page.List {
					// 查询产品信息
					productId := v["productId"].(primitive.ObjectID)
					supplyId := v["supplyId"].(primitive.ObjectID)
					product := model.Product{}
					supply := model.Supply{}
					repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
						CollectName: repo.CollectionProduct,
						Query:       repo.Map{"_id": productId},
						Project:     []string{"name", "unit", "cover"},
					}, &product)
					repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
						CollectName: repo.CollectionSupply,
						Query:       repo.Map{"_id": supplyId},
						Project:     []string{"name"},
					}, &supply)
					v["productName"] = product.Name
					v["productUnit"] = product.Unit
					v["productCover"] = product.Cover
					v["supplyName"] = supply.Name

				}
			}
			return page, nil
		},
	})
}
